==> kubernetes-model-1.0.61-sources.jar: annotations/io/fabric8/kubernetes/api/model/VsphereVirtualDiskVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Object;

public class VsphereVirtualDiskVolumeSourceFluentImpl<A extends VsphereVirtualDiskVolumeSourceFluent<A>> extends BaseFluent<A> implements VsphereVirtualDiskVolumeSourceFluent<A>{

    private String fsType;
    private String volumePath;

    public VsphereVirtualDiskVolumeSourceFluentImpl(){
    }
    public VsphereVirtualDiskVolumeSourceFluentImpl(VsphereVirtualDiskVolumeSource instance){
            this.withFsType(instance.getFsType()); 
            this.withVolumePath(instance.getVolumePath()); 
    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public String getVolumePath(){
            return this.volumePath;
    }

    public A withVolumePath(String volumePath){
            this.volumePath=volumePath; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            VsphereVirtualDiskVolumeSourceFluentImpl that = (VsphereVirtualDiskVolumeSourceFluentImpl) o;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (volumePath != null ? !volumePath.equals(that.volumePath) :that.volumePath != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.76-sources.jar: annotations/io/fabric8/kubernetes/api/model/VsphereVirtualDiskVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class VsphereVirtualDiskVolumeSourceFluentImpl<A extends VsphereVirtualDiskVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements VsphereVirtualDiskVolumeSourceFluent<A>{

    private String fsType;
    private String volumePath;

    public VsphereVirtualDiskVolumeSourceFluentImpl(){
    }
    public VsphereVirtualDiskVolumeSourceFluentImpl(VsphereVirtualDiskVolumeSource instance){
            this.withFsType(instance.getFsType()); 
            this.withVolumePath(instance.getVolumePath()); 
    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType(){
            return this.fsType!=null;
    }

    public String getVolumePath(){
            return this.volumePath;
    }

    public A withVolumePath(String volumePath){
            this.volumePath=volumePath; return (A) this;
    }

    public Boolean hasVolumePath(){
            return this.volumePath!=null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            VsphereVirtualDiskVolumeSourceFluentImpl that = (VsphereVirtualDiskVolumeSourceFluentImpl) o;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (volumePath != null ? !volumePath.equals(that.volumePath) :that.volumePath != null) return false;
            return true;
    }




}
